# Invpy package v1.1.0

- Package that includes several methods to compute statistical translation non-invariance of primarly, but not limitted to, scalar
cosmological fields.

## Update

- Added common.py method that has two routines in it, spectrum_estimate and split_spectrum. The latter is to compute
the power spectrum estimator for a single input cosmological field realization; 
